==> aws_prototyping_sdk.open_api_gateway-0.9.1.tar.gz: package/lib/project/samples/java.d.ts <==
/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */
export interface JavaSampleCodeOptions {
    /**
     * The package name which exports the OpenApiGatewayLambdaApi construct (ie this pdk package!)
     */
    readonly openApiGatewayPackageName: string;
    /**
     * Whether or not to generate sample code
     */
    readonly sampleCode?: boolean;
    /**
     * Api source code directory, relative to the project root
     */
    readonly apiSrcDir: string;
    /**
     * Directory where the parsed spec is output
     */
    readonly specDir: string;
    /**
     * Name of the parsed spec file
     */
    readonly parsedSpecFileName: string;
    /**
     * The package from which to import generated java client classes
     */
    readonly javaClientPackage: string;
}
export declare const getJavaSampleSource: (options: JavaSampleCodeOptions) => {
    [fileName: string]: string;
};

==> aws_prototyping_sdk.open_api_gateway-0.11.0.tar.gz: package/lib/project/samples/java.d.ts <==
/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */
export interface JavaSampleCodeOptions {
    /**
     * The package name which exports the OpenApiGatewayRestApi construct (ie this pdk package!)
     */
    readonly openApiGatewayPackageName: string;
    /**
     * Whether or not to generate sample code
     */
    readonly sampleCode?: boolean;
    /**
     * Api source code directory, relative to the project root
     */
    readonly apiSrcDir: string;
    /**
     * Directory where the parsed spec is output
     */
    readonly specDir: string;
    /**
     * Name of the parsed spec file
     */
    readonly parsedSpecFileName: string;
    /**
     * The package from which to import generated java client classes
     */
    readonly javaClientPackage: string;
}
export declare const getJavaSampleSource: (options: JavaSampleCodeOptions) => {
    [fileName: string]: string;
};
